part of '../vrchat_dart.dart';

/// A response from the VRChat API
class VrcResponse {
  /// The error returned from the API if any
  final VrcError? error;

  VrcResponse({this.error});
}

/// A response from the auth API
class AuthResponse extends VrcResponse {
  /// True if this account requires two factor auth
  final bool requiresTwoFactorAuth;

  /// Create an [AuthResonse]
  AuthResponse({
    this.requiresTwoFactorAuth = false,
    VrcError? error,
  }) : super(error: error);
}

/// An error returned from the VRChat API
class VrcError {
  /// Error message returned from the API
  final String message;

  /// Status code returned from the API
  final int statusCode;

  /// Construct a [VrcError] from json
  VrcError.fromJson(Map<String, dynamic> json)
      : this.message = json['error']['message'],
        this.statusCode = json['error']['status_code'];

  /// toString override
  @override
  String toString() {
    return '$statusCode: $message';
  }
}
